@@ -22,7 +22,11 @@ def grid_to_dict(grid):
 
 def write_to_file(score, grids, filename=None):
     filename = filename or os.path.join(macht_data_dir, 'default_save.json')
-    os.makedirs(os.path.dirname(filename), exist_ok=True)
+    try:
+        os.makedirs(os.path.dirname(filename))
+    except getattr(__builtins__, 'FileExistsError', OSError) as err:
+        if err.errno != 17:  # py2: OSerror but not file exists
+            raise
 
     contents = {'score': score,
                 'grids': [grid_to_dict(grid) for grid in grids]}
@@ -37,5 +41,7 @@ def load_from_file(filename=None):
     try:
         with open(filename) as save_file:
             return json.load(save_file)
-    except FileNotFoundError:
+    except getattr(__builtins__, 'FileNotFoundError', IOError) as err:
+        if err.errno != 2:  # py2: IOerror but not file not found
+            raise
         return {}
